blocks_to_block_start = {
    0: "Basic Latin",
    128: "Latin-1 Supplement",
    256: "Latin Extended-A",
    384: "Latin Extended-B",
    592: "IPA Extensions",
    688: "Spacing Modifier Letters",
    768: "Combining Diacritical Marks",
    880: "Greek and Coptic",
    1024: "Cyrillic",
    1280: "Cyrillic Supplement",
    1328: "Armenian",
    1424: "Hebrew",
    1536: "Arabic",
    1792: "Syriac",
    1872: "Arabic Supplement",
    1920: "Thaana",
    1984: "NKo",
    2048: "Samaritan",
    2112: "Mandaic",
    2144: "Syriac Supplement",
    2208: "Arabic Extended-A",
    2304: "Devanagari",
    2432: "Bengali",
    2560: "Gurmukhi",
    2688: "Gujarati",
    2816: "Oriya",
    2944: "Tamil",
    3072: "Telugu",
    3200: "Kannada",
    3328: "Malayalam",
    3456: "Sinhala",
    3584: "Thai",
    3712: "Lao",
    3840: "Tibetan",
    4096: "Myanmar",
    4256: "Georgian",
    4352: "Hangul Jamo",
    4608: "Ethiopic",
    4992: "Ethiopic Supplement",
    5024: "Cherokee",
    5120: "Unified Canadian Aboriginal Syllabics",
    5760: "Ogham",
    5792: "Runic",
    5888: "Tagalog",
    5920: "Hanunoo",
    5952: "Buhid",
    5984: "Tagbanwa",
    6016: "Khmer",
    6144: "Mongolian",
    6320: "Unified Canadian Aboriginal Syllabics Extended",
    6400: "Limbu",
    6480: "Tai Le",
    6528: "New Tai Lue",
    6624: "Khmer Symbols",
    6656: "Buginese",
    6688: "Tai Tham",
    6832: "Combining Diacritical Marks Extended",
    6912: "Balinese",
    7040: "Sundanese",
    7104: "Batak",
    7168: "Lepcha",
    7248: "Ol Chiki",
    7296: "Cyrillic Extended-C",
    7312: "Georgian Extended",
    7360: "Sundanese Supplement",
    7376: "Vedic Extensions",
    7424: "Phonetic Extensions",
    7552: "Phonetic Extensions Supplement",
    7616: "Combining Diacritical Marks Supplement",
    7680: "Latin Extended Additional",
    7936: "Greek Extended",
    8192: "General Punctuation",
    8304: "Superscripts and Subscripts",
    8352: "Currency Symbols",
    8400: "Combining Diacritical Marks for Symbols",
    8448: "Letterlike Symbols",
    8528: "Number Forms",
    8592: "Arrows",
    8704: "Mathematical Operators",
    8960: "Miscellaneous Technical",
    9216: "Control Pictures",
    9280: "Optical Character Recognition",
    9312: "Enclosed Alphanumerics",
    9472: "Box Drawing",
    9600: "Block Elements",
    9632: "Geometric Shapes",
    9728: "Miscellaneous Symbols",
    9984: "Dingbats",
    10176: "Miscellaneous Mathematical Symbols-A",
    10224: "Supplemental Arrows-A",
    10240: "Braille Patterns",
    10496: "Supplemental Arrows-B",
    10624: "Miscellaneous Mathematical Symbols-B",
    10752: "Supplemental Mathematical Operators",
    11008: "Miscellaneous Symbols and Arrows",
    11264: "Glagolitic",
    11360: "Latin Extended-C",
    11392: "Coptic",
    11520: "Georgian Supplement",
    11568: "Tifinagh",
    11648: "Ethiopic Extended",
    11744: "Cyrillic Extended-A",
    11776: "Supplemental Punctuation",
    11904: "CJK Radicals Supplement",
    12032: "Kangxi Radicals",
    12272: "Ideographic Description Characters",
    12288: "CJK Symbols and Punctuation",
    12352: "Hiragana",
    12448: "Katakana",
    12544: "Bopomofo",
    12592: "Hangul Compatibility Jamo",
    12688: "Kanbun",
    12704: "Bopomofo Extended",
    12736: "CJK Strokes",
    12784: "Katakana Phonetic Extensions",
    12800: "Enclosed CJK Letters and Months",
    13056: "CJK Compatibility",
    13312: "CJK Unified Ideographs Extension A",
    19904: "Yijing Hexagram Symbols",
    19968: "CJK Unified Ideographs",
    40960: "Yi Syllables",
    42128: "Yi Radicals",
    42192: "Lisu",
    42240: "Vai",
    42560: "Cyrillic Extended-B",
    42656: "Bamum",
    42752: "Modifier Tone Letters",
    42784: "Latin Extended-D",
    43008: "Syloti Nagri",
    43056: "Common Indic Number Forms",
    43072: "Phags-pa",
    43136: "Saurashtra",
    43232: "Devanagari Extended",
    43264: "Kayah Li",
    43312: "Rejang",
    43360: "Hangul Jamo Extended-A",
    43392: "Javanese",
    43488: "Myanmar Extended-B",
    43520: "Cham",
    43616: "Myanmar Extended-A",
    43648: "Tai Viet",
    43744: "Meetei Mayek Extensions",
    43776: "Ethiopic Extended-A",
    43824: "Latin Extended-E",
    43888: "Cherokee Supplement",
    43968: "Meetei Mayek",
    44032: "Hangul Syllables",
    55216: "Hangul Jamo Extended-B",
    55296: "High Surrogates",
    56192: "High Private Use Surrogates",
    56320: "Low Surrogates",
    57344: "Private Use Area",
    63744: "CJK Compatibility Ideographs",
    64256: "Alphabetic Presentation Forms",
    64336: "Arabic Presentation Forms-A",
    65024: "Variation Selectors",
    65040: "Vertical Forms",
    65056: "Combining Half Marks",
    65072: "CJK Compatibility Forms",
    65104: "Small Form Variants",
    65136: "Arabic Presentation Forms-B",
    65280: "Halfwidth and Fullwidth Forms",
    65520: "Specials",
    65536: "Linear B Syllabary",
    65664: "Linear B Ideograms",
    65792: "Aegean Numbers",
    65856: "Ancient Greek Numbers",
    65936: "Ancient Symbols",
    66000: "Phaistos Disc",
    66176: "Lycian",
    66208: "Carian",
    66272: "Coptic Epact Numbers",
    66304: "Old Italic",
    66352: "Gothic",
    66384: "Old Permic",
    66432: "Ugaritic",
    66464: "Old Persian",
    66560: "Deseret",
    66640: "Shavian",
    66688: "Osmanya",
    66736: "Osage",
    66816: "Elbasan",
    66864: "Caucasian Albanian",
    67072: "Linear A",
    67584: "Cypriot Syllabary",
    67648: "Imperial Aramaic",
    67680: "Palmyrene",
    67712: "Nabataean",
    67808: "Hatran",
    67840: "Phoenician",
    67872: "Lydian",
    67968: "Meroitic Hieroglyphs",
    68000: "Meroitic Cursive",
    68096: "Kharoshthi",
    68192: "Old South Arabian",
    68224: "Old North Arabian",
    68288: "Manichaean",
    68352: "Avestan",
    68416: "Inscriptional Parthian",
    68448: "Inscriptional Pahlavi",
    68480: "Psalter Pahlavi",
    68608: "Old Turkic",
    68736: "Old Hungarian",
    68864: "Hanifi Rohingya",
    69216: "Rumi Numeral Symbols",
    69248: "Yezidi",
    69376: "Old Sogdian",
    69424: "Sogdian",
    69552: "Chorasmian",
    69600: "Elymaic",
    69632: "Brahmi",
    69760: "Kaithi",
    69840: "Sora Sompeng",
    69888: "Chakma",
    69968: "Mahajani",
    70016: "Sharada",
    70112: "Sinhala Archaic Numbers",
    70144: "Khojki",
    70272: "Multani",
    70320: "Khudawadi",
    70400: "Grantha",
    70656: "Newa",
    70784: "Tirhuta",
    71040: "Siddham",
    71168: "Modi",
    71264: "Mongolian Supplement",
    71296: "Takri",
    71424: "Ahom",
    71680: "Dogra",
    71840: "Warang Citi",
    71936: "Dives Akuru",
    72096: "Nandinagari",
    72192: "Zanabazar Square",
    72272: "Soyombo",
    72384: "Pau Cin Hau",
    72704: "Bhaiksuki",
    72816: "Marchen",
    72960: "Masaram Gondi",
    73056: "Gunjala Gondi",
    73440: "Makasar",
    73648: "Lisu Supplement",
    73664: "Tamil Supplement",
    73728: "Cuneiform",
    74752: "Cuneiform Numbers and Punctuation",
    74880: "Early Dynastic Cuneiform",
    77824: "Egyptian Hieroglyphs",
    78896: "Egyptian Hieroglyph Format Controls",
    82944: "Anatolian Hieroglyphs",
    92160: "Bamum Supplement",
    92736: "Mro",
    92880: "Bassa Vah",
    92928: "Pahawh Hmong",
    93760: "Medefaidrin",
    93952: "Miao",
    94176: "Ideographic Symbols and Punctuation",
    94208: "Tangut",
    100352: "Tangut Components",
    101120: "Khitan Small Script",
    101632: "Tangut Supplement",
    110592: "Kana Supplement",
    110848: "Kana Extended-A",
    110896: "Small Kana Extension",
    110960: "Nushu",
    113664: "Duployan",
    113824: "Shorthand Format Controls",
    118784: "Byzantine Musical Symbols",
    119040: "Musical Symbols",
    119296: "Ancient Greek Musical Notation",
    119520: "Mayan Numerals",
    119552: "Tai Xuan Jing Symbols",
    119648: "Counting Rod Numerals",
    119808: "Mathematical Alphanumeric Symbols",
    120832: "Sutton SignWriting",
    122880: "Glagolitic Supplement",
    123136: "Nyiakeng Puachue Hmong",
    123584: "Wancho",
    124928: "Mende Kikakui",
    125184: "Adlam",
    126064: "Indic Siyaq Numbers",
    126208: "Ottoman Siyaq Numbers",
    126464: "Arabic Mathematical Alphabetic Symbols",
    126976: "Mahjong Tiles",
    127024: "Domino Tiles",
    127136: "Playing Cards",
    127232: "Enclosed Alphanumeric Supplement",
    127488: "Enclosed Ideographic Supplement",
    127744: "Miscellaneous Symbols and Pictographs",
    128512: "Emoticons",
    128592: "Ornamental Dingbats",
    128640: "Transport and Map Symbols",
    128768: "Alchemical Symbols",
    128896: "Geometric Shapes Extended",
    129024: "Supplemental Arrows-C",
    129280: "Supplemental Symbols and Pictographs",
    129536: "Chess Symbols",
    129648: "Symbols and Pictographs Extended-A",
    129792: "Symbols for Legacy Computing",
    131072: "CJK Unified Ideographs Extension B",
    173824: "CJK Unified Ideographs Extension C",
    177984: "CJK Unified Ideographs Extension D",
    178208: "CJK Unified Ideographs Extension E",
    183984: "CJK Unified Ideographs Extension F",
    194560: "CJK Compatibility Ideographs Supplement",
    196608: "CJK Unified Ideographs Extension G",
    917504: "Tags",
    917760: "Variation Selectors Supplement",
    983040: "Supplementary Private Use Area-A",
    1048576: "Supplementary Private Use Area-B",
}



property_value_alias_blk_long_to_short = {
    "Adlam": "Adlam",
    "Aegean Numbers": "Aegean Numbers",
    "Ahom": "Ahom",
    "Alchemical Symbols": "Alchemical",
    "Alphabetic Presentation Forms": "Alphabetic PF",
    "Anatolian Hieroglyphs": "Anatolian Hieroglyphs",
    "Ancient Greek Musical Notation": "Ancient Greek Music",
    "Ancient Greek Numbers": "Ancient Greek Numbers",
    "Ancient Symbols": "Ancient Symbols",
    "Arabic": "Arabic",
    "Arabic Extended A": "Arabic Ext A",
    "Arabic Mathematical Alphabetic Symbols": "Arabic Math",
    "Arabic Presentation Forms A": "Arabic PF A",
    "Arabic Presentation Forms B": "Arabic PF B",
    "Arabic Supplement": "Arabic Sup",
    "Armenian": "Armenian",
    "Arrows": "Arrows",
    "Avestan": "Avestan",
    "Balinese": "Balinese",
    "Bamum": "Bamum",
    "Bamum Supplement": "Bamum Sup",
    "Basic Latin": "ASCII",
    "Bassa Vah": "Bassa Vah",
    "Batak": "Batak",
    "Bengali": "Bengali",
    "Bhaiksuki": "Bhaiksuki",
    "Block Elements": "Block Elements",
    "Bopomofo": "Bopomofo",
    "Bopomofo Extended": "Bopomofo Ext",
    "Box Drawing": "Box Drawing",
    "Brahmi": "Brahmi",
    "Braille Patterns": "Braille",
    "Buginese": "Buginese",
    "Buhid": "Buhid",
    "Byzantine Musical Symbols": "Byzantine Music",
    "CJK Compatibility": "CJK Compat",
    "CJK Compatibility Forms": "CJK Compat Forms",
    "CJK Compatibility Ideographs": "CJK Compat Ideographs",
    "CJK Compatibility Ideographs Supplement": "CJK Compat Ideographs Sup",
    "CJK Radicals Supplement": "CJK Radicals Sup",
    "CJK Strokes": "CJK Strokes",
    "CJK Symbols And Punctuation": "CJK Symbols",
    "CJK Unified Ideographs": "CJK",
    "CJK Unified Ideographs Extension A": "CJK Ext A",
    "CJK Unified Ideographs Extension B": "CJK Ext B",
    "CJK Unified Ideographs Extension C": "CJK Ext C",
    "CJK Unified Ideographs Extension D": "CJK Ext D",
    "CJK Unified Ideographs Extension E": "CJK Ext E",
    "CJK Unified Ideographs Extension F": "CJK Ext F",
    "CJK Unified Ideographs Extension G": "CJK Ext G",
    "Carian": "Carian",
    "Caucasian Albanian": "Caucasian Albanian",
    "Chakma": "Chakma",
    "Cham": "Cham",
    "Cherokee": "Cherokee",
    "Cherokee Supplement": "Cherokee Sup",
    "Chess Symbols": "Chess Symbols",
    "Chorasmian": "Chorasmian",
    "Combining Diacritical Marks": "Diacriticals",
    "Combining Diacritical Marks Extended": "Diacriticals Ext",
    "Combining Diacritical Marks For Symbols": "Diacriticals For Symbols",
    "Combining Diacritical Marks Supplement": "Diacriticals Sup",
    "Combining Half Marks": "Half Marks",
    "Common Indic Number Forms": "Indic Number Forms",
    "Control Pictures": "Control Pictures",
    "Coptic": "Coptic",
    "Coptic Epact Numbers": "Coptic Epact Numbers",
    "Counting Rod Numerals": "Counting Rod",
    "Cuneiform": "Cuneiform",
    "Cuneiform Numbers And Punctuation": "Cuneiform Numbers",
    "Currency Symbols": "Currency Symbols",
    "Cypriot Syllabary": "Cypriot Syllabary",
    "Cyrillic": "Cyrillic",
    "Cyrillic Extended A": "Cyrillic Ext A",
    "Cyrillic Extended B": "Cyrillic Ext B",
    "Cyrillic Extended C": "Cyrillic Ext C",
    "Cyrillic Supplement": "Cyrillic Sup",
    "Deseret": "Deseret",
    "Devanagari": "Devanagari",
    "Devanagari Extended": "Devanagari Ext",
    "Dingbats": "Dingbats",
    "Dives Akuru": "Dives Akuru",
    "Dogra": "Dogra",
    "Domino Tiles": "Domino",
    "Duployan": "Duployan",
    "Early Dynastic Cuneiform": "Early Dynastic Cuneiform",
    "Egyptian Hieroglyph Format Controls": "Egyptian Hieroglyph Format Controls",
    "Egyptian Hieroglyphs": "Egyptian Hieroglyphs",
    "Elbasan": "Elbasan",
    "Elymaic": "Elymaic",
    "Emoticons": "Emoticons",
    "Enclosed Alphanumeric Supplement": "Enclosed Alphanum Sup",
    "Enclosed Alphanumerics": "Enclosed Alphanum",
    "Enclosed CJK Letters And Months": "Enclosed CJK",
    "Enclosed Ideographic Supplement": "Enclosed Ideographic Sup",
    "Ethiopic": "Ethiopic",
    "Ethiopic Extended": "Ethiopic Ext",
    "Ethiopic Extended A": "Ethiopic Ext A",
    "Ethiopic Supplement": "Ethiopic Sup",
    "General Punctuation": "Punctuation",
    "Geometric Shapes": "Geometric Shapes",
    "Geometric Shapes Extended": "Geometric Shapes Ext",
    "Georgian": "Georgian",
    "Georgian Extended": "Georgian Ext",
    "Georgian Supplement": "Georgian Sup",
    "Glagolitic": "Glagolitic",
    "Glagolitic Supplement": "Glagolitic Sup",
    "Gothic": "Gothic",
    "Grantha": "Grantha",
    "Greek And Coptic": "Greek",
    "Greek Extended": "Greek Ext",
    "Gujarati": "Gujarati",
    "Gunjala Gondi": "Gunjala Gondi",
    "Gurmukhi": "Gurmukhi",
    "Halfwidth And Fullwidth Forms": "Half And Full Forms",
    "Hangul Compatibility Jamo": "Compat Jamo",
    "Hangul Jamo": "Jamo",
    "Hangul Jamo Extended A": "Jamo Ext A",
    "Hangul Jamo Extended B": "Jamo Ext B",
    "Hangul Syllables": "Hangul",
    "Hanifi Rohingya": "Hanifi Rohingya",
    "Hanunoo": "Hanunoo",
    "Hatran": "Hatran",
    "Hebrew": "Hebrew",
    "High Private Use Surrogates": "High PU Surrogates",
    "High Surrogates": "High Surrogates",
    "Hiragana": "Hiragana",
    "IPA Extensions": "IPA Ext",
    "Ideographic Description Characters": "IDC",
    "Ideographic Symbols And Punctuation": "Ideographic Symbols",
    "Imperial Aramaic": "Imperial Aramaic",
    "Indic Siyaq Numbers": "Indic Siyaq Numbers",
    "Inscriptional Pahlavi": "Inscriptional Pahlavi",
    "Inscriptional Parthian": "Inscriptional Parthian",
    "Javanese": "Javanese",
    "Kaithi": "Kaithi",
    "Kana Extended A": "Kana Ext A",
    "Kana Supplement": "Kana Sup",
    "Kanbun": "Kanbun",
    "Kangxi Radicals": "Kangxi",
    "Kannada": "Kannada",
    "Katakana": "Katakana",
    "Katakana Phonetic Extensions": "Katakana Ext",
    "Kayah Li": "Kayah Li",
    "Kharoshthi": "Kharoshthi",
    "Khitan Small Script": "Khitan Small Script",
    "Khmer": "Khmer",
    "Khmer Symbols": "Khmer Symbols",
    "Khojki": "Khojki",
    "Khudawadi": "Khudawadi",
    "Lao": "Lao",
    "Latin 1 Supplement": "Latin 1 Sup",
    "Latin Extended A": "Latin Ext A",
    "Latin Extended Additional": "Latin Ext Additional",
    "Latin Extended B": "Latin Ext B",
    "Latin Extended C": "Latin Ext C",
    "Latin Extended D": "Latin Ext D",
    "Latin Extended E": "Latin Ext E",
    "Lepcha": "Lepcha",
    "Letterlike Symbols": "Letterlike Symbols",
    "Limbu": "Limbu",
    "Linear A": "Linear A",
    "Linear B Ideograms": "Linear B Ideograms",
    "Linear B Syllabary": "Linear B Syllabary",
    "Lisu": "Lisu",
    "Lisu Supplement": "Lisu Sup",
    "Low Surrogates": "Low Surrogates",
    "Lycian": "Lycian",
    "Lydian": "Lydian",
    "Mahajani": "Mahajani",
    "Mahjong Tiles": "Mahjong",
    "Makasar": "Makasar",
    "Malayalam": "Malayalam",
    "Mandaic": "Mandaic",
    "Manichaean": "Manichaean",
    "Marchen": "Marchen",
    "Masaram Gondi": "Masaram Gondi",
    "Mathematical Alphanumeric Symbols": "Math Alphanum",
    "Mathematical Operators": "Math Operators",
    "Mayan Numerals": "Mayan Numerals",
    "Medefaidrin": "Medefaidrin",
    "Meetei Mayek": "Meetei Mayek",
    "Meetei Mayek Extensions": "Meetei Mayek Ext",
    "Mende Kikakui": "Mende Kikakui",
    "Meroitic Cursive": "Meroitic Cursive",
    "Meroitic Hieroglyphs": "Meroitic Hieroglyphs",
    "Miao": "Miao",
    "Miscellaneous Mathematical Symbols A": "Misc Math Symbols A",
    "Miscellaneous Mathematical Symbols B": "Misc Math Symbols B",
    "Miscellaneous Symbols": "Misc Symbols",
    "Miscellaneous Symbols And Arrows": "Misc Arrows",
    "Miscellaneous Symbols And Pictographs": "Misc Pictographs",
    "Miscellaneous Technical": "Misc Technical",
    "Modi": "Modi",
    "Modifier Tone Letters": "Modifier Tone Letters",
    "Mongolian": "Mongolian",
    "Mongolian Supplement": "Mongolian Sup",
    "Mro": "Mro",
    "Multani": "Multani",
    "Musical Symbols": "Music",
    "Myanmar": "Myanmar",
    "Myanmar Extended A": "Myanmar Ext A",
    "Myanmar Extended B": "Myanmar Ext B",
    "NKo": "NKo",
    "Nabataean": "Nabataean",
    "Nandinagari": "Nandinagari",
    "New Tai Lue": "New Tai Lue",
    "Newa": "Newa",
    "No Block": "NB",
    "Number Forms": "Number Forms",
    "Nushu": "Nushu",
    "Nyiakeng Puachue Hmong": "Nyiakeng Puachue Hmong",
    "Ogham": "Ogham",
    "Ol Chiki": "Ol Chiki",
    "Old Hungarian": "Old Hungarian",
    "Old Italic": "Old Italic",
    "Old North Arabian": "Old North Arabian",
    "Old Permic": "Old Permic",
    "Old Persian": "Old Persian",
    "Old Sogdian": "Old Sogdian",
    "Old South Arabian": "Old South Arabian",
    "Old Turkic": "Old Turkic",
    "Optical Character Recognition": "OCR",
    "Oriya": "Oriya",
    "Ornamental Dingbats": "Ornamental Dingbats",
    "Osage": "Osage",
    "Osmanya": "Osmanya",
    "Ottoman Siyaq Numbers": "Ottoman Siyaq Numbers",
    "Pahawh Hmong": "Pahawh Hmong",
    "Palmyrene": "Palmyrene",
    "Pau Cin Hau": "Pau Cin Hau",
    "Phags Pa": "Phags Pa",
    "Phaistos Disc": "Phaistos",
    "Phoenician": "Phoenician",
    "Phonetic Extensions": "Phonetic Ext",
    "Phonetic Extensions Supplement": "Phonetic Ext Sup",
    "Playing Cards": "Playing Cards",
    "Private Use Area": "PUA",
    "Psalter Pahlavi": "Psalter Pahlavi",
    "Rejang": "Rejang",
    "Rumi Numeral Symbols": "Rumi",
    "Runic": "Runic",
    "Samaritan": "Samaritan",
    "Saurashtra": "Saurashtra",
    "Sharada": "Sharada",
    "Shavian": "Shavian",
    "Shorthand Format Controls": "Shorthand Format Controls",
    "Siddham": "Siddham",
    "Sinhala": "Sinhala",
    "Sinhala Archaic Numbers": "Sinhala Archaic Numbers",
    "Small Form Variants": "Small Forms",
    "Small Kana Extension": "Small Kana Ext",
    "Sogdian": "Sogdian",
    "Sora Sompeng": "Sora Sompeng",
    "Soyombo": "Soyombo",
    "Spacing Modifier Letters": "Modifier Letters",
    "Specials": "Specials",
    "Sundanese": "Sundanese",
    "Sundanese Supplement": "Sundanese Sup",
    "Superscripts And Subscripts": "Super And Sub",
    "Supplemental Arrows A": "Sup Arrows A",
    "Supplemental Arrows B": "Sup Arrows B",
    "Supplemental Arrows C": "Sup Arrows C",
    "Supplemental Mathematical Operators": "Sup Math Operators",
    "Supplemental Punctuation": "Sup Punctuation",
    "Supplemental Symbols And Pictographs": "Sup Symbols And Pictographs",
    "Supplementary Private Use Area A": "Sup PUA A",
    "Supplementary Private Use Area B": "Sup PUA B",
    "Sutton SignWriting": "Sutton SignWriting",
    "Syloti Nagri": "Syloti Nagri",
    "Symbols And Pictographs Extended A": "Symbols And Pictographs Ext A",
    "Symbols For Legacy Computing": "Symbols For Legacy Computing",
    "Syriac": "Syriac",
    "Syriac Supplement": "Syriac Sup",
    "Tagalog": "Tagalog",
    "Tagbanwa": "Tagbanwa",
    "Tags": "Tags",
    "Tai Le": "Tai Le",
    "Tai Tham": "Tai Tham",
    "Tai Viet": "Tai Viet",
    "Tai Xuan Jing Symbols": "Tai Xuan Jing",
    "Takri": "Takri",
    "Tamil": "Tamil",
    "Tamil Supplement": "Tamil Sup",
    "Tangut": "Tangut",
    "Tangut Components": "Tangut Components",
    "Tangut Supplement": "Tangut Sup",
    "Telugu": "Telugu",
    "Thaana": "Thaana",
    "Thai": "Thai",
    "Tibetan": "Tibetan",
    "Tifinagh": "Tifinagh",
    "Tirhuta": "Tirhuta",
    "Transport And Map Symbols": "Transport And Map",
    "Ugaritic": "Ugaritic",
    "Unified Canadian Aboriginal Syllabics": "UCAS",
    "Unified Canadian Aboriginal Syllabics Extended": "UCAS Ext",
    "Vai": "Vai",
    "Variation Selectors": "VS",
    "Variation Selectors Supplement": "VS Sup",
    "Vedic Extensions": "Vedic Ext",
    "Vertical Forms": "Vertical Forms",
    "Wancho": "Wancho",
    "Warang Citi": "Warang Citi",
    "Yezidi": "Yezidi",
    "Yi Radicals": "Yi Radicals",
    "Yi Syllables": "Yi Syllables",
    "Yijing Hexagram Symbols": "Yijing",
    "Zanabazar Square": "Zanabazar Square",
}
